# DISCLAIMER

**DO NOT USE**

This repository is a temporary clone&patch of Google's own keyring implementation available [here](https://github.com/GoogleCloudPlatform/artifact-registry-python-tools).

**DO NOT USE**
